# IChain: Interactive Chain-Building for LLMs

Main features:

- Ability to cheaply and interactively build a chain of LLM calls
- Ability to integrate LLM results with regular Python functions
- Ability to evaluate LLM chains on many examples in parallel
